@@ -19,7 +19,8 @@ def generate_apkbuild(args, pkgname, deviceinfo, patches):
                 KBUILD_BUILD_VERSION="$((pkgrel + 1 ))-postmarketOS\""""
 
     package = """
-            downstreamkernel_package "$builddir" "$pkgdir" "$_carch" "$_flavor" "$_outdir\""""
+            downstreamkernel_package "$builddir" "$pkgdir" "$_carch\" \\
+                "$_flavor" "$_outdir\""""
 
     if deviceinfo["bootimg_qcdt"] == "true":
         build += """\n
@@ -30,19 +31,20 @@ def generate_apkbuild(args, pkgname, deviceinfo, patches):
         if soc_vendor == "spreadtrum":
             makedepends.append("dtbtool-sprd")
             build += """
-            dtbTool-sprd -p scripts/dtc/ \\
+            dtbTool-sprd -p "$_outdir/scripts/dtc/" \\
                 -o "$_outdir/arch/$_carch/boot"/dt.img \\
                 "$_outdir/arch/$_carch/boot/dts/\""""
         elif soc_vendor == "exynos":
             codename = "-".join(pkgname.split("-")[2:])
             makedepends.append("dtbtool-exynos")
-            build += f"""
+            build += """
             dtbTool-exynos -o "$_outdir/arch/$_carch/boot"/dt.img \\
-                $(find "$_outdir/arch/$_carch/boot/dts/" -name *{codename}*.dtb)"""
+                $(find "$_outdir/arch/$_carch/boot/dts/\""""
+            build += f" -name *{codename}*.dtb)"
         else:
             makedepends.append("dtbtool")
             build += """
-            dtbTool -p scripts/dtc/ -o "$_outdir/arch/$_carch/boot"/dt.img \\
+            dtbTool -o "$_outdir/arch/$_carch/boot"/dt.img \\
                 "$_outdir/arch/$_carch/boot/\""""
         package += """
             install -Dm644 "$_outdir/arch/$_carch/boot"/dt.img \\
