@@ -15,7 +15,7 @@ from pmb.config.merge_with_args import merge_with_args
 #
 # Exported variables (internal configuration)
 #
-version = "1.36.0"
+version = "1.38.0"
 pmb_src = os.path.normpath(os.path.realpath(__file__) + "/../../..")
 apk_keys_path = pmb_src + "/pmb/data/keys"
 
@@ -24,7 +24,7 @@ apk_keys_path = pmb_src + "/pmb/data/keys"
 # Update this frequently to prevent a MITM attack with an outdated version
 # (which may contain a vulnerable apk/openssl, and allows an attacker to
 # exploit the system!)
-apk_tools_min_version = {"edge": "2.12.7-r0",
+apk_tools_min_version = {"edge": "2.12.7-r3",
                          "v3.14": "2.12.7-r0",
                          "v3.13": "2.12.7-r0",
                          "v3.12": "2.10.8-r0"}
@@ -191,7 +191,7 @@ chroot_path = ":".join([
 # for the chroot executable may not be in the PATH (Debian).
 chroot_host_path = os.environ["PATH"] + ":/usr/sbin/"
 
-# Folders, that get mounted inside the chroot
+# Folders that get mounted inside the chroot
 # $WORK gets replaced with args.work
 # $ARCH gets replaced with the chroot architecture (eg. x86_64, armhf)
 # $CHANNEL gets replaced with the release channel (e.g. edge, v21.03)
@@ -251,7 +251,7 @@ chroot_outdated = 3600 * 24 * 2
 # packages (use "pmbootstrap aportgen musl-armhf" etc.).
 build_device_architectures = ["armhf", "armv7", "aarch64", "x86_64", "x86"]
 
-# Packages, that will be installed in a chroot before it builds packages
+# Packages that will be installed in a chroot before it builds packages
 # for the first time
 build_packages = ["abuild", "build-base", "ccache", "git"]
 
@@ -319,6 +319,12 @@ necessary_kconfig_options_anbox = {
             "BRIDGE_VLAN_FILTERING": True,
         }
     },
+    ">=4.20.0": {
+        "all": {
+            "PSI": True,  # required by userspace OOM killer in Waydroid
+            "PSI_DEFAULT_DISABLED": False,
+        }
+    }
 }
 
 # Necessary nftables kernel config options
@@ -498,7 +504,7 @@ apkbuild_package_attributes = {
     "_pmb_groups": {"array": True},
 }
 
-# Variables in APKBUILD files, that get parsed
+# Variables in APKBUILD files that get parsed
 apkbuild_attributes = {
     **apkbuild_package_attributes,
 
@@ -580,9 +586,11 @@ deviceinfo_attributes = [
     "flash_heimdall_partition_initfs",
     "flash_heimdall_partition_system",
     "flash_heimdall_partition_vbmeta",
+    "flash_heimdall_partition_dtbo",
     "flash_fastboot_partition_kernel",
     "flash_fastboot_partition_system",
     "flash_fastboot_partition_vbmeta",
+    "flash_fastboot_partition_dtbo",
     "generate_legacy_uboot_initfs",
     "kernel_cmdline",
     "generate_bootimg",
@@ -637,7 +645,7 @@ default_ip = "172.16.42.1"
 # INSTALL
 #
 
-# Packages, that will be installed inside the native chroot to perform
+# Packages that will be installed inside the native chroot to perform
 # the installation to the device.
 # util-linux: losetup, fallocate
 install_native_packages = ["cryptsetup", "util-linux", "parted"]
@@ -666,7 +674,7 @@ Flasher abstraction. Allowed variables:
 
 $BOOT: Path to the /boot partition
 $DTB: Set to "-dtb" if deviceinfo_append_dtb is set, otherwise ""
-$FLAVOR: Kernel flavor
+$FLAVOR: Backwards compatibility with old mkinitfs (pma#660)
 $IMAGE: Path to the combined boot/rootfs image
 $IMAGE_SPLIT_BOOT: Path to the (split) boot image
 $IMAGE_SPLIT_ROOT: Path to the (split) rootfs image
@@ -685,7 +693,7 @@ flashers = {
             "flash_rootfs": [["fastboot", "flash", "$PARTITION_SYSTEM",
                               "$IMAGE"]],
             "flash_kernel": [["fastboot", "flash", "$PARTITION_KERNEL",
-                              "$BOOT/boot.img-$FLAVOR"]],
+                              "$BOOT/boot.img$FLAVOR"]],
             "flash_vbmeta": [
                 # Generate vbmeta image with "disable verification" flag
                 ["avbtool", "make_vbmeta_image", "--flags", "2",
@@ -694,8 +702,10 @@ flashers = {
                 ["fastboot", "flash", "$PARTITION_VBMETA", "/vbmeta.img"],
                 ["rm", "-f", "/vbmeta.img"]
             ],
+            "flash_dtbo": [["fastboot", "flash", "$PARTITION_DTBO",
+                            "$BOOT/dtbo.img"]],
             "boot": [["fastboot", "--cmdline", "$KERNEL_CMDLINE",
-                      "boot", "$BOOT/boot.img-$FLAVOR"]],
+                      "boot", "$BOOT/boot.img$FLAVOR"]],
         },
     },
     # Some devices provide Fastboot but using Android boot images is not
@@ -729,8 +739,8 @@ flashers = {
                 ["heimdall_wait_for_device.sh"],
                 ["heimdall", "flash", "--$PARTITION_SYSTEM", "$IMAGE"]],
             "flash_kernel": [["heimdall_flash_kernel.sh",
-                              "$BOOT/initramfs-$FLAVOR", "$PARTITION_INITFS",
-                              "$BOOT/vmlinuz-$FLAVOR$DTB",
+                              "$BOOT/initramfs$FLAVOR", "$PARTITION_INITFS",
+                              "$BOOT/vmlinuz$FLAVOR$DTB",
                               "$PARTITION_KERNEL"]]
         },
     },
@@ -746,7 +756,7 @@ flashers = {
             "flash_kernel": [
                 ["heimdall_wait_for_device.sh"],
                 ["heimdall", "flash", "--$PARTITION_KERNEL",
-                 "$BOOT/boot.img-$FLAVOR"]],
+                 "$BOOT/boot.img$FLAVOR"]],
             "flash_vbmeta": [
                 ["avbtool", "make_vbmeta_image", "--flags", "2",
                     "--padding_size", "$FLASH_PAGESIZE",
