@@ -42,8 +42,7 @@ def kernel(args):
 def list_flavors(args):
     suffix = "rootfs_" + args.device
     logging.info("(" + suffix + ") installed kernel flavors:")
-    for flavor in pmb.chroot.other.kernel_flavors_installed(args, suffix):
-        logging.info("* " + flavor)
+    logging.info("* " + pmb.chroot.other.kernel_flavor_installed(args, suffix))
 
 
 def rootfs(args):
@@ -79,6 +78,11 @@ def flash_vbmeta(args):
     pmb.flasher.run(args, "flash_vbmeta")
 
 
+def flash_dtbo(args):
+    logging.info("(native) flash dtbo image")
+    pmb.flasher.run(args, "flash_dtbo")
+
+
 def list_devices(args):
     pmb.flasher.run(args, "list_devices")
 
@@ -126,6 +130,8 @@ def frontend(args):
         rootfs(args)
     if action == "flash_vbmeta":
         flash_vbmeta(args)
+    if action == "flash_dtbo":
+        flash_dtbo(args)
     if action == "list_flavors":
         list_flavors(args)
     if action == "list_devices":
