@@ -42,6 +42,15 @@ def run(args, action, flavor=None):
                            " <https://wiki.postmarketos.org/wiki/"
                            "Deviceinfo_reference>")
 
+    # dtbo flasher requires dtbo partition to be explicitly specified
+    if action == "flash_dtbo" and not vars["$PARTITION_DTBO"]:
+        raise RuntimeError("Your device does not have 'dtbo' partition"
+                           " specified; set"
+                           " 'deviceinfo_flash_fastboot_partition_dtbo'"
+                           " in deviceinfo file. See also:"
+                           " <https://wiki.postmarketos.org/wiki/"
+                           "Deviceinfo_reference>")
+
     # Run the commands of each action
     for command in cfg["actions"][action]:
         # Variable replacement
