@@ -1,5 +1,6 @@
 # Copyright 2021 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
+import pmb.config.pmaports
 
 
 def variables(args, flavor, method):
@@ -16,6 +17,8 @@ def variables(args, flavor, method):
             or "system"
         _partition_vbmeta = args.deviceinfo["flash_fastboot_partition_vbmeta"]\
             or None
+        _partition_dtbo = args.deviceinfo["flash_fastboot_partition_dtbo"]\
+            or None
     else:
         _partition_kernel = args.deviceinfo["flash_heimdall_partition_kernel"]\
             or "KERNEL"
@@ -23,13 +26,16 @@ def variables(args, flavor, method):
             or "SYSTEM"
         _partition_vbmeta = args.deviceinfo["flash_heimdall_partition_vbmeta"]\
             or None
+        _partition_dtbo = args.deviceinfo["flash_heimdall_partition_dtbo"]\
+            or None
 
     if "partition" in args and args.partition:
-        # Only one of operations is done at same time so it doesn't matter
+        # Only one operation is done at same time so it doesn't matter
         # sharing the arg
         _partition_kernel = args.partition
         _partition_system = args.partition
         _partition_vbmeta = args.partition
+        _partition_dtbo = args.partition
 
     _dtb = ""
     if args.deviceinfo["append_dtb"] == "true":
@@ -38,7 +44,6 @@ def variables(args, flavor, method):
     vars = {
         "$BOOT": "/mnt/rootfs_" + args.device + "/boot",
         "$DTB": _dtb,
-        "$FLAVOR": flavor if flavor is not None else "",
         "$IMAGE_SPLIT_BOOT": "/home/pmos/rootfs/" + args.device + "-boot.img",
         "$IMAGE_SPLIT_ROOT": "/home/pmos/rootfs/" + args.device + "-root.img",
         "$IMAGE": "/home/pmos/rootfs/" + args.device + ".img",
@@ -48,6 +53,7 @@ def variables(args, flavor, method):
             "flash_heimdall_partition_initfs"] or "RECOVERY",
         "$PARTITION_SYSTEM": _partition_system,
         "$PARTITION_VBMETA": _partition_vbmeta,
+        "$PARTITION_DTBO": _partition_dtbo,
         "$FLASH_PAGESIZE": flash_pagesize,
         "$RECOVERY_ZIP": "/mnt/buildroot_" + args.deviceinfo["arch"] +
                          "/var/lib/postmarketos-android-recovery-installer"
@@ -56,4 +62,11 @@ def variables(args, flavor, method):
                        "/usr/share/uuu/flash_script.lst"
     }
 
+    # Backwards compatibility with old mkinitfs (pma#660)
+    pmaports_cfg = pmb.config.pmaports.read_config(args)
+    if pmaports_cfg.get("supported_mkinitfs_without_flavors", False):
+        vars["$FLAVOR"] = ""
+    else:
+        vars["$FLAVOR"] = f"-{flavor}" if flavor is not None else "-"
+
     return vars
