@@ -38,24 +38,19 @@ def _parse_flavor(args, autoinstall=True):
     Verify the flavor argument if specified, or return a default value.
     :param autoinstall: make sure that at least one kernel flavor is installed
     """
-    # Install at least one kernel and get installed flavors
+    # Install a kernel and get its "flavor", where flavor is a pmOS-specific
+    # identifier that is typically in the form
+    # "postmarketos-<manufacturer>-<device/chip>", e.g.
+    # "postmarketos-qcom-sdm845"
     suffix = "rootfs_" + args.device
-    flavors = pmb.chroot.other.kernel_flavors_installed(
+    flavor = pmb.chroot.other.kernel_flavor_installed(
         args, suffix, autoinstall)
 
-    # Parse and verify the flavor argument
-    flavor = args.flavor
-    if flavor:
-        if flavor not in flavors:
-            raise RuntimeError(f"No kernel installed with flavor {flavor}!" +
-                               " Run 'pmbootstrap flasher list_flavors' to"
-                               " get a list.")
-        return flavor
-    if not len(flavors):
+    if not flavor:
         raise RuntimeError(
             "No kernel flavors installed in chroot " + suffix + "! Please let"
             " your device package depend on a package starting with 'linux-'.")
-    return flavors[0]
+    return flavor
 
 
 def _parse_suffix(args):
@@ -422,12 +417,13 @@ def kconfig(args):
                 logging.info("NOTE: " + str(skipped) + " kernel(s) was skipped"
                              " (consider 'pmbootstrap kconfig check -f')")
             logging.info("kconfig check succeeded!")
-    elif args.action_kconfig == "edit":
+    elif args.action_kconfig in ["edit", "migrate"]:
         if args.package:
             pkgname = args.package
         else:
             pkgname = args.deviceinfo["codename"]
-        pmb.build.menuconfig(args, pkgname)
+        use_oldconfig = args.action_kconfig == "migrate"
+        pmb.build.menuconfig(args, pkgname, use_oldconfig)
 
 
 def deviceinfo_parse(args):
@@ -591,8 +587,7 @@ def lint(args):
     if not packages:
         packages = pmb.helpers.pmaports.get_list(args)
 
-    for package in packages:
-        pmb.helpers.lint.check(args, package)
+    pmb.helpers.lint.check(args, packages)
 
 
 def status(args):
