@@ -391,12 +391,10 @@ def print_firewall_info(args):
     apkbuild_has_opt = False
 
     arch = args.deviceinfo["arch"]
-    suffix = f"rootfs_{args.device}"
-    kernels = pmb.chroot.other.kernel_flavors_installed(args, suffix,
-                                                        autoinstall=False)
-    if kernels:
-        kernel = f"linux-{kernels[0]}"
-        kernel_apkbuild = pmb.build._package.get_apkbuild(args, kernel, arch)
+    kernel = get_kernel_package(args, args.device)
+    if kernel:
+        kernel_apkbuild = pmb.build._package.get_apkbuild(args, kernel[0],
+                                                          arch)
         if kernel_apkbuild:
             opts = kernel_apkbuild["options"]
             apkbuild_has_opt = "pmb:kconfigcheck-nftables" in opts
@@ -673,6 +671,14 @@ def print_flash_info(args):
         logging.info("* pmbootstrap flasher flash_vbmeta")
         logging.info("  Flashes vbmeta image with verification disabled flag.")
 
+    # if current flasher supports dtbo and partition is explicitly specified
+    # in deviceinfo
+    if "flash_dtbo" in flasher_actions and \
+            (args.deviceinfo["flash_fastboot_partition_dtbo"] or
+             args.deviceinfo["flash_heimdall_partition_dtbo"]):
+        logging.info("* pmbootstrap flasher flash_dtbo")
+        logging.info("  Flashes dtbo image.")
+
     # Most flash methods operate independently of the boot partition.
     # (e.g. an Android boot image is generated). In that case, "flash_kernel"
     # works even when partitions are split or installing for sdcard.
@@ -840,8 +846,8 @@ def create_device_rootfs(args, step, steps):
     # because that doesn't always happen automatically yet, e.g. when the user
     # installed a hook without pmbootstrap - see #69 for more info)
     pmb.chroot.apk.install(args, install_packages, suffix)
-    for flavor in pmb.chroot.other.kernel_flavors_installed(args, suffix):
-        pmb.chroot.initfs.build(args, flavor, suffix)
+    flavor = pmb.chroot.other.kernel_flavor_installed(args, suffix)
+    pmb.chroot.initfs.build(args, flavor, suffix)
 
     # Set the user password
     setup_login(args, suffix)
