@@ -88,8 +88,6 @@ def arguments_install(subparser):
     # Image type "--android-recovery-zip" related
     group = ret.add_argument_group("optional image type 'android-recovery-zip'"
                                    " arguments")
-    group.add_argument("--flavor", help="kernel flavor to include in recovery"
-                       " flashable zip", default=None)
     group.add_argument("--recovery-install-partition", default="system",
                        help="partition to flash from recovery (e.g."
                             " 'external_sd')",
@@ -174,7 +172,6 @@ def arguments_export(subparser):
     ret.add_argument("--odin", help="odin flashable tar"
                                     " (boot.img/kernel+initramfs only)",
                      action="store_true", dest="odin_flashable_tar")
-    ret.add_argument("--flavor", default=None)
     ret.add_argument("--no-install", dest="autoinstall", default=True,
                      help="skip updating kernel/initfs", action="store_false")
     return ret
@@ -213,7 +210,6 @@ def arguments_flasher(subparser):
     boot.add_argument("--cmdline", help="override kernel commandline")
     flash_kernel = sub.add_parser("flash_kernel", help="flash a kernel")
     for action in [boot, flash_kernel]:
-        action.add_argument("--flavor", default=None)
         action.add_argument("--no-install", dest="autoinstall", default=True,
                             help="skip updating kernel/initfs",
                             action="store_false")
@@ -242,6 +238,13 @@ def arguments_flasher(subparser):
                               help="partition to flash the vbmeta to (defaults"
                                    " to deviceinfo_flash_*_partition_vbmeta")
 
+    # Flash dtbo
+    flash_dtbo = sub.add_parser("flash_dtbo",
+                                help="flash dtbo image")
+    flash_dtbo.add_argument("--partition", default=None,
+                            help="partition to flash the dtbo to (defaults"
+                            " to deviceinfo_flash_*_partition_dtbo)")
+
     # Actions without extra arguments
     sub.add_parser("sideload", help="sideload recovery zip")
     sub.add_parser("list_flavors", help="list installed kernel flavors" +
@@ -270,17 +273,10 @@ def arguments_initfs(subparser):
                             " for example: 'debug-shell'")
 
     # ls, build, extract
-    ls = sub.add_parser("ls", help="list initramfs contents")
-    build = sub.add_parser("build", help="(re)build the initramfs")
-    extract = sub.add_parser(
-        "extract",
-        help="extract the initramfs to a temporary folder")
-    for action in [ls, build, extract]:
-        action.add_argument(
-            "--flavor",
-            default=None,
-            help="name of the kernel flavor (run 'pmbootstrap flasher"
-            " list_flavors' to get a list of all installed flavors")
+    sub.add_parser("ls", help="list initramfs contents")
+    sub.add_parser("build", help="(re)build the initramfs")
+    sub.add_parser("extract",
+                   help="extract the initramfs to a temporary folder")
 
     return ret
 
@@ -359,7 +355,8 @@ def arguments_pkgrel_bump(subparser):
 
 
 def arguments_aportupgrade(subparser):
-    ret = subparser.add_parser("aportupgrade")
+    ret = subparser.add_parser("aportupgrade", help="check for outdated"
+                               " packages that need upgrading")
     ret.add_argument("--dry", action="store_true", help="instead of modifying"
                      " APKBUILDs, print the changes that would be made")
     ret.add_argument("--ref", help="git ref (tag, commit, etc) to use")
@@ -460,6 +457,17 @@ def arguments_kconfig(subparser):
     if argcomplete:
         edit_package.completer = kernel_completer
 
+    # "pmbootstrap kconfig migrate"
+    migrate = sub.add_parser("migrate",
+                             help="Migrate kconfig from older version to "
+                                  "newer. Internally runs 'make oldconfig', "
+                                  "which asks question for every new kernel "
+                                  "config option.")
+    migrate.add_argument("--arch", choices=arch_choices, dest="arch")
+    migrate_package = migrate.add_argument("package", nargs='?')
+    if argcomplete:
+        migrate_package.completer = kernel_completer
+
 
 def arguments_repo_missing(subparser):
     ret = subparser.add_parser("repo_missing")
